diff mbox series

[v3,2/4] mm: Rename zap_skip_check_mapping() to should_zap_page()

Message ID 20220128045412.18695-3-peterx@redhat.com (mailing list archive)
State New
Headers show
Series mm: Rework zap ptes on swap entries | expand

Commit Message

Peter Xu Jan. 28, 2022, 4:54 a.m. UTC
The previous name is against the natural way people think.  Invert the meaning
and also the return value.  No functional change intended.

Suggested-by: Hugh Dickins <hughd@google.com>
Signed-off-by: Peter Xu <peterx@redhat.com>
---
 mm/memory.c | 17 ++++++++---------
 1 file changed, 8 insertions(+), 9 deletions(-)

Comments

David Hildenbrand Jan. 28, 2022, 8:16 a.m. UTC | #1
On 28.01.22 05:54, Peter Xu wrote:
> The previous name is against the natural way people think.  Invert the meaning
> and also the return value.  No functional change intended.
> 
> Suggested-by: Hugh Dickins <hughd@google.com>

Could have sworn it was me :P

> Signed-off-by: Peter Xu <peterx@redhat.com>
> ---

Reviewed-by: David Hildenbrand <david@redhat.com>
Peter Xu Jan. 28, 2022, 8:53 a.m. UTC | #2
On Fri, Jan 28, 2022 at 09:16:07AM +0100, David Hildenbrand wrote:
> On 28.01.22 05:54, Peter Xu wrote:
> > The previous name is against the natural way people think.  Invert the meaning
> > and also the return value.  No functional change intended.
> > 
> > Suggested-by: Hugh Dickins <hughd@google.com>
> 
> Could have sworn it was me :P

Yeah it's possible. :)

I'll add both of you in the next version if there is.

> 
> > Signed-off-by: Peter Xu <peterx@redhat.com>
> > ---
> 
> Reviewed-by: David Hildenbrand <david@redhat.com>

Thanks,
diff mbox series

Patch

diff --git a/mm/memory.c b/mm/memory.c
index 4bfeaca7cbc7..14d8428ff4db 100644
--- a/mm/memory.c
+++ b/mm/memory.c
@@ -1326,20 +1326,19 @@  static inline bool should_zap_cows(struct zap_details *details)
 
 /*
  * We set details->zap_mapping when we want to unmap shared but keep private
  * pages. Return true if skip zapping this page, false otherwise.
  */
-static inline bool
-zap_skip_check_mapping(struct zap_details *details, struct page *page)
+static inline bool should_zap_page(struct zap_details *details, struct page *page)
 {
 	/* If we can make a decision without *page.. */
 	if (should_zap_cows(details))
-		return false;
+		return true;
 
 	/* E.g. zero page */
 	if (!page)
-		return false;
+		return true;
 
-	return details->zap_mapping != page_rmapping(page);
+	return details->zap_mapping == page_rmapping(page);
 }
 
 static unsigned long zap_pte_range(struct mmu_gather *tlb,
@@ -1374,7 +1373,7 @@  static unsigned long zap_pte_range(struct mmu_gather *tlb,
 			struct page *page;
 
 			page = vm_normal_page(vma, addr, ptent);
-			if (unlikely(zap_skip_check_mapping(details, page)))
+			if (unlikely(!should_zap_page(details, page)))
 				continue;
 			ptent = ptep_get_and_clear_full(mm, addr, pte,
 							tlb->fullmm);
@@ -1408,7 +1407,7 @@  static unsigned long zap_pte_range(struct mmu_gather *tlb,
 		    is_device_exclusive_entry(entry)) {
 			struct page *page = pfn_swap_entry_to_page(entry);
 
-			if (unlikely(zap_skip_check_mapping(details, page)))
+			if (unlikely(!should_zap_page(details, page)))
 				continue;
 			pte_clear_not_present_full(mm, addr, pte, tlb->fullmm);
 			rss[mm_counter(page)]--;
@@ -1433,7 +1432,7 @@  static unsigned long zap_pte_range(struct mmu_gather *tlb,
 			struct page *page;
 
 			page = pfn_swap_entry_to_page(entry);
-			if (zap_skip_check_mapping(details, page))
+			if (!should_zap_page(details, page))
 				continue;
 			rss[mm_counter(page)]--;
 		} else if (is_hwpoison_entry(entry)) {
@@ -1326,20 +1326,19 @@  static inline bool should_zap_cows(struct zap_details *details)
 /*
  * We set details->zap_mapping when we want to unmap shared but keep private
- * pages. Return true if skip zapping this page, false otherwise.
+ * pages. Return true if we should zap this page, false otherwise.
  */